# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingVo2MaxChangedEventType(str, enum.Enum):
    DAILY_DATA_VO_2_MAX_CREATED = "daily.data.vo2_max.created"
    DAILY_DATA_VO_2_MAX_UPDATED = "daily.data.vo2_max.updated"

    def visit(
        self,
        daily_data_vo_2_max_created: typing.Callable[[], T_Result],
        daily_data_vo_2_max_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingVo2MaxChangedEventType.DAILY_DATA_VO_2_MAX_CREATED:
            return daily_data_vo_2_max_created()
        if self is ClientFacingVo2MaxChangedEventType.DAILY_DATA_VO_2_MAX_UPDATED:
            return daily_data_vo_2_max_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingElectrocardiogramSourceType(str, enum.Enum):
    UNKNOWN = "unknown"
    PHONE = "phone"
    WATCH = "watch"
    APP = "app"
    MULTIPLE_SOURCES = "multiple_sources"
    FINGERPRICK = "fingerprick"
    CUFF = "cuff"
    MANUAL_SCAN = "manual_scan"
    AUTOMATIC = "automatic"
    SCALE = "scale"
    CHEST_STRAP = "chest_strap"
    RING = "ring"
    LAB = "lab"

    def visit(
        self,
        unknown: typing.Callable[[], T_Result],
        phone: typing.Callable[[], T_Result],
        watch: typing.Callable[[], T_Result],
        app: typing.Callable[[], T_Result],
        multiple_sources: typing.Callable[[], T_Result],
        fingerprick: typing.Callable[[], T_Result],
        cuff: typing.Callable[[], T_Result],
        manual_scan: typing.Callable[[], T_Result],
        automatic: typing.Callable[[], T_Result],
        scale: typing.Callable[[], T_Result],
        chest_strap: typing.Callable[[], T_Result],
        ring: typing.Callable[[], T_Result],
        lab: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingElectrocardiogramSourceType.UNKNOWN:
            return unknown()
        if self is ClientFacingElectrocardiogramSourceType.PHONE:
            return phone()
        if self is ClientFacingElectrocardiogramSourceType.WATCH:
            return watch()
        if self is ClientFacingElectrocardiogramSourceType.APP:
            return app()
        if self is ClientFacingElectrocardiogramSourceType.MULTIPLE_SOURCES:
            return multiple_sources()
        if self is ClientFacingElectrocardiogramSourceType.FINGERPRICK:
            return fingerprick()
        if self is ClientFacingElectrocardiogramSourceType.CUFF:
            return cuff()
        if self is ClientFacingElectrocardiogramSourceType.MANUAL_SCAN:
            return manual_scan()
        if self is ClientFacingElectrocardiogramSourceType.AUTOMATIC:
            return automatic()
        if self is ClientFacingElectrocardiogramSourceType.SCALE:
            return scale()
        if self is ClientFacingElectrocardiogramSourceType.CHEST_STRAP:
            return chest_strap()
        if self is ClientFacingElectrocardiogramSourceType.RING:
            return ring()
        if self is ClientFacingElectrocardiogramSourceType.LAB:
            return lab()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .client_facing_sample_grouping_keys import ClientFacingSampleGroupingKeys
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingBodyWeightTimeseries(UniversalBaseModel):
    id: typing.Optional[int] = pydantic.Field(default=None)
    """
    Deprecated
    """

    timezone_offset: typing.Optional[int] = pydantic.Field(default=None)
    """
    Time zone UTC offset in seconds. Positive offset indicates east of UTC; negative offset indicates west of UTC; and null indicates the time zone information is unavailable at source.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The reading type of the measurement. This is applicable only to Cholesterol, IGG, IGE and InsulinInjection.
    """

    unit: str = pydantic.Field()
    """
    Measured in kilograms (kg).
    """

    grouping: typing.Optional[ClientFacingSampleGroupingKeys] = None
    timestamp: dt.datetime = pydantic.Field()
    """
    The timestamp of the measurement.
    """

    value: float = pydantic.Field()
    """
    The value of the measurement.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingBloodPressureChangedEventType(str, enum.Enum):
    DAILY_DATA_BLOOD_PRESSURE_CREATED = "daily.data.blood_pressure.created"
    DAILY_DATA_BLOOD_PRESSURE_UPDATED = "daily.data.blood_pressure.updated"

    def visit(
        self,
        daily_data_blood_pressure_created: typing.Callable[[], T_Result],
        daily_data_blood_pressure_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingBloodPressureChangedEventType.DAILY_DATA_BLOOD_PRESSURE_CREATED:
            return daily_data_blood_pressure_created()
        if self is ClientFacingBloodPressureChangedEventType.DAILY_DATA_BLOOD_PRESSURE_UPDATED:
            return daily_data_blood_pressure_updated()
